%bcond_with bootstrap
# temporalily ignore test failures
# due to https://github.com/golang/go/issues/39466
#ifarch aarch64
%bcond_without ignore_tests
#else
#bcond_with ignore_tests
#endif

# build ids are not currently generated:
# https://code.google.com/p/go/issues/detail?id=5238
#
# also, debuginfo extraction currently fails with
# "Failed to write file: invalid section alignment"
%global debug_package %{nil}

# we are shipping the full contents of src in the data subpackage, which
# contains binary-like things (ELF data for tests, etc)
%global _binaries_in_noarch_packages_terminate_build 0

# Do not check any files in doc or src for requires
%global __requires_exclude_from ^(%{_datadir}|/usr/lib)/%{name}/(doc|src)/.*$

# Don't alter timestamps of especially the .a files (or else go will rebuild later)
# Actually, don't strip at all since we are not even building debug packages and this corrupts the dwarf testdata
%global __strip /bin/true

# rpmbuild magic to keep from having meta dependency on libc.so.6
%define _use_internal_dependency_generator 0
%define __find_requires %{nil}
%global __spec_install_post /usr/lib/rpm/check-rpaths   /usr/lib/rpm/check-buildroot  \
  /usr/lib/rpm/brp-compress

%global golibdir %{_libdir}/golang

# This macro may not always be defined, ensure it is
%{!?gopath: %global gopath %{_datadir}/gocode}

# Golang build options.

# Build golang using external/internal(close to cgo disabled) linking.
%ifarch %{ix86} x86_64 ppc64le %{arm} aarch64 s390x
%global external_linker 1
%else
%global external_linker 0
%endif

# Build golang with cgo enabled/disabled(later equals more or less to internal linking).
%ifarch %{ix86} x86_64 ppc64le %{arm} aarch64 s390x
%global cgo_enabled 1
%else
%global cgo_enabled 0
%endif

# Use golang/gcc-go as bootstrap compiler
%if %{with bootstrap}
%global golang_bootstrap 0
%else
%global golang_bootstrap 1
%endif

# Controls what ever we fail on failed tests
%if %{with ignore_tests}
%global fail_on_tests 0
%else
%global fail_on_tests 1
%endif

# Build golang shared objects for stdlib
%ifarch %{ix86} x86_64 ppc64le %{arm} aarch64
%global shared 1
%else
%global shared 0
%endif

# Pre build std lib with -race enabled
%ifarch x86_64
%global race 1
%else
%global race 0
%endif

# Mageia GOROOT
%global goroot          /usr/lib/%{name}

%ifarch x86_64
%global gohostarch  amd64
%endif
%ifarch %{ix86}
%global gohostarch  386
%endif
%ifarch %{arm}
%global gohostarch  arm
%endif
%ifarch aarch64
%global gohostarch  arm64
%endif

%global go_api 1.17
#global go_prerelease rc1
%global go_minor 11
%global go_version %{go_api}%{?go_minor:.%{go_minor}}%{?go_prerelease}

%global rel 1

Name:           golang
Version:        %{go_api}%{?go_minor:.%{go_minor}}
Release:        %mkrel %{?go_prerelease:0.%{go_prerelease}.}%{rel}
Summary:        The Go Programming Language
# source tree includes several copies of Mark.Twain-Tom.Sawyer.txt under Public Domain
Group:          Development/Other
License:        BSD and Public Domain
URL:            http://golang.org/
Source0:        https://storage.googleapis.com/golang/go%{go_version}.src.tar.gz
# make possible to override default traceback level at build time by setting build tag rpm_crashtraceback
Source1:        fedora.go

# The compiler is written in Go. Needs go(1.4+) compiler for build.
%if !%{golang_bootstrap}
BuildRequires:  gcc-go >= 5
%else
BuildRequires:  golang > 1.4
%endif
BuildRequires:  hostname
# for tests
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  glibc-devel
BuildRequires:  glibc-static-devel
BuildRequires:  procps-ng

Provides:       go = %{version}-%{release}
Requires:       %{name}-bin = %{version}-%{release}
Requires:       %{name}-src = %{version}-%{release}
Requires:       go-srpm-macros

Patch1:       0001-Don-t-use-the-bundled-tzdata-at-runtime-except-for-t.patch
Patch2:       0002-syscall-expose-IfInfomsg.X__ifi_pad-on-s390x.patch
#Patch3:       0003-cmd-go-disable-Google-s-proxy-and-sumdb.patch

# Having documentation separate was broken
Obsoletes:      %{name}-docs < 1.1-4

# RPM can't handle symlink -> dir with subpackages, so merge back
Obsoletes:      %{name}-data < 1.1.1-4

# go1.4 deprecates a few packages
Obsoletes:      %{name}-vim < 1.4
Obsoletes:      emacs-%{name} < 1.4

Source100:      golang-gdbinit
Source101:      golang-prelink.conf

%description
%{summary}.

%package       docs
Summary:       Golang compiler docs
Group:         Development/Other
Requires:      %{name} = %{version}-%{release}
BuildArch:     noarch
Obsoletes:     %{name}-docs < 1.1-4

%description   docs
%{summary}.

%package       misc
Summary:       Golang compiler miscellaneous sources
Group:         Development/Other
Requires:      %{name} = %{version}-%{release}
BuildArch:     noarch

%description   misc
%{summary}.

%package       tests
Summary:       Golang compiler tests for stdlib
Group:         Development/Other
Requires:      %{name} = %{version}-%{release}
BuildArch:     noarch

%description   tests
%{summary}.

%package        src
Summary:        Golang compiler source tree
Group:          Development/Other
BuildArch:      noarch
%description    src
%{summary}

%package        bin
Summary:        Golang core compiler tools
Group:          Development/Other
Requires:       go = %{version}-%{release}
# Pre-go1.5, all arches had to be bootstrapped individually, before usable, and
# env variables to compile for the target os-arch.
# Now the host compiler needs only the GOOS and GOARCH environment variables
# set to compile for the target os-arch.
Obsoletes:      %{name}-pkg-bin-linux-386 < 1.4.99
Obsoletes:      %{name}-pkg-bin-linux-amd64 < 1.4.99
Obsoletes:      %{name}-pkg-bin-linux-arm < 1.4.99
Obsoletes:      %{name}-pkg-linux-386 < 1.4.99
Obsoletes:      %{name}-pkg-linux-amd64 < 1.4.99
Obsoletes:      %{name}-pkg-linux-arm < 1.4.99
Obsoletes:      %{name}-pkg-darwin-386 < 1.4.99
Obsoletes:      %{name}-pkg-darwin-amd64 < 1.4.99
Obsoletes:      %{name}-pkg-windows-386 < 1.4.99
Obsoletes:      %{name}-pkg-windows-amd64 < 1.4.99
Obsoletes:      %{name}-pkg-plan9-386 < 1.4.99
Obsoletes:      %{name}-pkg-plan9-amd64 < 1.4.99
Obsoletes:      %{name}-pkg-freebsd-386 < 1.4.99
Obsoletes:      %{name}-pkg-freebsd-amd64 < 1.4.99
Obsoletes:      %{name}-pkg-freebsd-arm < 1.4.99
Obsoletes:      %{name}-pkg-netbsd-386 < 1.4.99
Obsoletes:      %{name}-pkg-netbsd-amd64 < 1.4.99
Obsoletes:      %{name}-pkg-netbsd-arm < 1.4.99
Obsoletes:      %{name}-pkg-openbsd-386 < 1.4.99
Obsoletes:      %{name}-pkg-openbsd-amd64 < 1.4.99

Requires(post): %{_sbindir}/update-alternatives
Requires(preun): %{_sbindir}/update-alternatives

# We strip the meta dependency, but go does require glibc.
# This is an odd issue, still looking for a better fix.
Requires:       glibc
Requires:       gcc
%description    bin
%{summary}

# Workaround old RPM bug of symlink-replaced-with-dir failure
%pretrans -p <lua>
for _,d in pairs({"api", "doc", "include", "lib", "src"}) do
  path = "%{goroot}/" .. d
  if posix.stat(path, "type") == "link" then
    os.remove(path)
    posix.mkdir(path)
  end
end

%if %{shared}
%package        shared
Summary:        Golang shared object libraries
Group:          Development/Other

%description    shared
%{summary}.
%endif

%if %{race}
%package        race
Summary:        Golang std library with -race enabled

Requires:       %{name} = %{version}-%{release}

%description    race
%{summary}.
%endif

%prep
%autosetup -p1 -n go

cp %{SOURCE1} ./src/runtime/

%build
# print out system information
uname -a
cat /proc/cpuinfo
cat /proc/meminfo

# bootstrap compiler GOROOT
%if !%{golang_bootstrap}
export GOROOT_BOOTSTRAP=/
%else
export GOROOT_BOOTSTRAP=%{goroot}
%endif

# set up final install location
export GOROOT_FINAL=%{goroot}

export GOHOSTOS=linux
export GOHOSTARCH=%{gohostarch}

pushd src
# use our gcc options for this build, but store gcc as default for compiler
export CFLAGS="$RPM_OPT_FLAGS"
export LDFLAGS="$RPM_LD_FLAGS"
export CC="gcc"
export CC_FOR_TARGET="gcc"
export GOOS=linux
export GOARCH=%{gohostarch}
%if !%{external_linker}
export GO_LDFLAGS="-linkmode internal"
%endif
%if !%{cgo_enabled}
export CGO_ENABLED=0
%endif
./make.bash --no-clean -v
popd

# build shared std lib
%if %{shared}
GOROOT=$(pwd) PATH=$(pwd)/bin:$PATH go install -buildmode=shared -v -x std
%endif

%if %{race}
GOROOT=$(pwd) PATH=$(pwd)/bin:$PATH go install -race -v -x std
%endif

%install
rm -rf $RPM_BUILD_ROOT
# remove GC build cache
rm -rf pkg/obj/go-build/*

# create the top level directories
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{goroot}

# install everything into libdir (until symlink problems are fixed)
# https://code.google.com/p/go/issues/detail?id=5830
cp -apv api bin doc lib pkg src misc test VERSION \
   $RPM_BUILD_ROOT%{goroot}

# bz1099206
find $RPM_BUILD_ROOT%{goroot}/src -exec touch -r $RPM_BUILD_ROOT%{goroot}/VERSION "{}" \;
# and level out all the built archives
touch $RPM_BUILD_ROOT%{goroot}/pkg
find $RPM_BUILD_ROOT%{goroot}/pkg -exec touch -r $RPM_BUILD_ROOT%{goroot}/pkg "{}" \;
# generate the spec file ownership of this source tree and packages
cwd=$(pwd)
src_list=$cwd/go-src.list
pkg_list=$cwd/go-pkg.list
shared_list=$cwd/go-shared.list
race_list=$cwd/go-race.list
misc_list=$cwd/go-misc.list
docs_list=$cwd/go-docs.list
tests_list=$cwd/go-tests.list
rm -f $src_list $pkg_list $docs_list $misc_list $tests_list $shared_list $race_list
touch $src_list $pkg_list $docs_list $misc_list $tests_list $shared_list $race_list
pushd $RPM_BUILD_ROOT%{goroot}
    find src/ -type d -a \( ! -name testdata -a ! -ipath '*/testdata/*' \) -printf '%%%dir %{goroot}/%p\n' >> $src_list
    find src/ ! -type d -a \( ! -ipath '*/testdata/*' -a ! -name '*_test.go' \) -printf '%{goroot}/%p\n' >> $src_list

    find bin/ pkg/ -type d -a ! -path '*_dynlink/*' -a ! -path '*_race/*' -printf '%%%dir %{goroot}/%p\n' >> $pkg_list
    find bin/ pkg/ ! -type d -a ! -path '*_dynlink/*' -a ! -path '*_race/*' -printf '%{goroot}/%p\n' >> $pkg_list

    find doc/ -type d -printf '%%%dir %{goroot}/%p\n' >> $docs_list
    find doc/ ! -type d -printf '%{goroot}/%p\n' >> $docs_list

    find misc/ -type d -printf '%%%dir %{goroot}/%p\n' >> $misc_list
    find misc/ ! -type d -printf '%{goroot}/%p\n' >> $misc_list

%if %{shared}
    mkdir -p %{buildroot}/%{_libdir}/
    mkdir -p %{buildroot}/%{golibdir}/
    for file in $(find .  -iname "*.so" ); do
        chmod 755 $file
        mv  $file %{buildroot}/%{golibdir}
        pushd $(dirname $file)
        ln -fs %{golibdir}/$(basename $file) $(basename $file)
        popd
        echo "%%{goroot}/$file" >> $shared_list
        echo "%%{golibdir}/$(basename $file)" >> $shared_list
    done
    
    find pkg/*_dynlink/ -type d -printf '%%%dir %{goroot}/%p\n' >> $shared_list
    find pkg/*_dynlink/ ! -type d -printf '%{goroot}/%p\n' >> $shared_list
%endif

%if %{race}

    find pkg/*_race/ -type d -printf '%%%dir %{goroot}/%p\n' >> $race_list
    find pkg/*_race/ ! -type d -printf '%{goroot}/%p\n' >> $race_list

%endif

    find test/ -type d -printf '%%%dir %{goroot}/%p\n' >> $tests_list
    find test/ ! -type d -printf '%{goroot}/%p\n' >> $tests_list
    find src/ -type d -a \( -name testdata -o -ipath '*/testdata/*' \) -printf '%%%dir %{goroot}/%p\n' >> $tests_list
    find src/ ! -type d -a \( -ipath '*/testdata/*' -o -name '*_test.go' \) -printf '%{goroot}/%p\n' >> $tests_list
    # this is only the zoneinfo.zip
    find lib/ -type d -printf '%%%dir %{goroot}/%p\n' >> $tests_list
    find lib/ ! -type d -printf '%{goroot}/%p\n' >> $tests_list
popd

# remove the doc Makefile
rm -rfv $RPM_BUILD_ROOT%{goroot}/doc/Makefile

# put binaries to bindir, linked to the arch we're building,
# leave the arch independent pieces in {goroot}
mkdir -p $RPM_BUILD_ROOT%{goroot}/bin/linux_%{gohostarch}
ln -sf %{goroot}/bin/go $RPM_BUILD_ROOT%{goroot}/bin/linux_%{gohostarch}/go
ln -sf %{goroot}/bin/gofmt $RPM_BUILD_ROOT%{goroot}/bin/linux_%{gohostarch}/gofmt

# ensure these exist and are owned
mkdir -p $RPM_BUILD_ROOT%{gopath}/src/github.com
mkdir -p $RPM_BUILD_ROOT%{gopath}/src/bitbucket.org
mkdir -p $RPM_BUILD_ROOT%{gopath}/src/code.google.com/p
mkdir -p $RPM_BUILD_ROOT%{gopath}/src/golang.org/x

# make sure these files exist and point to alternatives
rm -f $RPM_BUILD_ROOT%{_bindir}/go
ln -sf /etc/alternatives/go $RPM_BUILD_ROOT%{_bindir}/go
rm -f $RPM_BUILD_ROOT%{_bindir}/gofmt
ln -sf /etc/alternatives/gofmt $RPM_BUILD_ROOT%{_bindir}/gofmt

# gdbinit
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/gdbinit.d
cp -av %{SOURCE100} $RPM_BUILD_ROOT%{_sysconfdir}/gdbinit.d/golang.gdb

%check
export GOROOT=$(pwd -P)
export PATH="$GOROOT"/bin:"$PATH"
cd src

export CC="gcc"
export CFLAGS="$RPM_OPT_FLAGS"
export LDFLAGS="$RPM_LD_FLAGS"
%if !%{external_linker}
export GO_LDFLAGS="-linkmode internal"
%endif
%if !%{cgo_enabled} || !%{external_linker}
export CGO_ENABLED=0
%endif
# workaround for https://github.com/golang/go/issues/39466 until it gests fixed
# Commented until the patch is ready, this workaround suggested in the link above
# doesn't work properly
#ifarch aarch64
#export CGO_CFLAGS="-mno-outline-atomics"
#endif

# make sure to not timeout
export GO_TEST_TIMEOUT_SCALE=2

%if %{fail_on_tests}
./run.bash --no-rebuild -v -v -v -k
%else
./run.bash --no-rebuild -v -v -v -k || :
%endif
cd ..


%post bin
%{_sbindir}/update-alternatives --install %{_bindir}/go \
    go %{goroot}/bin/go 90 \
    --slave %{_bindir}/gofmt gofmt %{goroot}/bin/gofmt

%preun bin
if [ $1 = 0 ]; then
    %{_sbindir}/update-alternatives --remove go %{goroot}/bin/go
fi


%files
%license LICENSE PATENTS
%doc AUTHORS CONTRIBUTORS
# VERSION has to be present in the GOROOT, for `go install std` to work
%doc %{goroot}/VERSION
%dir %{goroot}/doc
%doc %{goroot}/doc/*

# go files
%dir %{goroot}
%{goroot}/api/
%{goroot}/lib/time/

# ensure directory ownership, so they are cleaned up if empty
%dir %{gopath}
%dir %{gopath}/src
%dir %{gopath}/src/github.com/
%dir %{gopath}/src/bitbucket.org/
%dir %{gopath}/src/code.google.com/
%dir %{gopath}/src/code.google.com/p/
%dir %{gopath}/src/golang.org
%dir %{gopath}/src/golang.org/x


# gdbinit (for gdb debugging)
%{_sysconfdir}/gdbinit.d

%files src -f go-src.list

%files docs -f go-docs.list

%files misc -f go-misc.list

%files tests -f go-tests.list

%files bin -f go-pkg.list
%{_bindir}/go
%{_bindir}/gofmt
%{goroot}/bin/linux_%{gohostarch}/go
%{goroot}/bin/linux_%{gohostarch}/gofmt

%if %{shared}
%files shared -f go-shared.list
%endif

%if %{race}
%files race -f go-race.list
%endif


%changelog
* Mon Jun 13 2022 bcornec <bcornec> 1.17.11-1.mga8
+ Revision: 1864320
- Update go tp upstream 1.17.11 to fix mga#30530
- Update to upstream go 1.17.10 and fixes mga#30469
- Fix mga#30362 by updating golang to 1.17.9
- Fix mga#30217 with upstream upgrade to golang 1.17.8 - CVE-2022-24921
- Update to upstream docker-containerd 1.5.10 to fix mga#30111
- Update to upstream golang 1.17.5 to fix mga#29807
- Update to upstream 1.17.3 to fix mga#29717
+ neoclust <neoclust>
- Add P1000: Fixes CVE-2021-39293 (mga#29526)
+ ns80 <ns80>
- new version 1.15.15 for CVE-2021-36221 (mga#29391)
- new version 1.15.14 for CVE-2021-34558 (mga#29037)
- new version 1.15.13 for CVE-2021-27918, CVE-2021-31525, CVE-2021-3319[5-8] (mga#29037)

* Wed Jan 27 2021 neoclust <neoclust> 1.15.6-2.mga8
+ Revision: 1673760
- Add patches to fix CVE-2021-3114 and CVE-2021-3115 (mga#28228)

* Fri Dec 18 2020 joequant <joequant> 1.15.6-1.mga8
+ Revision: 1660635
- update to 1.15.6

* Thu Nov 26 2020 joequant <joequant> 1.15.5-1.mga8
+ Revision: 1649477
- update to 1.15.5 - fix 27650 - CVE-2020-2836[267]

* Fri Oct 16 2020 kekepower <kekepower> 1.15.3-1.mga8
+ Revision: 1636343
- Update to version 1.15.3

* Sun Sep 27 2020 joequant <joequant> 1.15.2-1.mga8
+ Revision: 1630789
- Fix #27324 - update to 0.15.2

* Thu Aug 13 2020 kekepower <kekepower> 1.15-1.mga8
+ Revision: 1613846
- Update to version 1.15

* Sat Aug 08 2020 kekepower <kekepower> 1.14.7-1.mga8
+ Revision: 1611957
- Update to version 1.14.7

* Tue Jul 21 2020 kekepower <kekepower> 1.14.6-2.mga8
+ Revision: 1607600
- Update to version 1.14.6

* Wed Jun 10 2020 joequant <joequant> 1.14.4-2.mga8
+ Revision: 1591569
- rebuild
- fix up bootstrap
- bootstrap

* Tue Jun 02 2020 kekepower <kekepower> 1.14.4-1.mga8
+ Revision: 1589748
- Update to version 1.14.4

* Mon May 18 2020 kekepower <kekepower> 1.14.3-1.mga8
+ Revision: 1586060
- Update to version 1.14.3

* Thu Apr 09 2020 kekepower <kekepower> 1.14.2-1.mga8
+ Revision: 1565857
- Update to version 1.14.2

* Wed Mar 25 2020 kekepower <kekepower> 1.14.1-1.mga8
+ Revision: 1560466
- Update to version 1.14.1

* Mon Feb 17 2020 umeabot <umeabot> 1.13.2-2.mga8
+ Revision: 1537289
- Mageia 8 Mass Rebuild

* Mon Oct 28 2019 bcornec <bcornec> 1.13.2-1.mga8
+ Revision: 1456444
- Update to upstream golang 1.13.2 and fixes mga#25616

* Wed Sep 04 2019 bcornec <bcornec> 1.13-1.mga8
+ Revision: 1437115
- Update goloang to upstream 1.13

* Wed Aug 14 2019 kekepower <kekepower> 1.12.8-1.mga8
+ Revision: 1429309
- Update to version 1.12.8

* Tue Jul 16 2019 kekepower <kekepower> 1.12.7-1.mga8
+ Revision: 1421931
- Update to version 1.12.7

* Mon May 13 2019 kekepower <kekepower> 1.12.5-1.mga7
+ Revision: 1397616
- Update to version 1.12.5

* Fri Apr 12 2019 kekepower <kekepower> 1.12.4-1.mga7
+ Revision: 1389448
- Update to version 1.12.4

* Tue Apr 09 2019 kekepower <kekepower> 1.12.3-1.mga7
+ Revision: 1387509
- Update to version 1.12.3

* Sat Apr 06 2019 kekepower <kekepower> 1.12.2-1.mga7
+ Revision: 1386443
- Update to version 1.12.2

* Sun Mar 17 2019 kekepower <kekepower> 1.12.1-1.mga7
+ Revision: 1378421
- Update to version 1.12.1

* Mon Mar 04 2019 kekepower <kekepower> 1.12-2.mga7
+ Revision: 1371553
- Update to version 1.12

* Tue Feb 05 2019 bcornec <bcornec> 1.11.5-2.mga7
+ Revision: 1363280
+ rebuild (emptylog)

* Tue Jan 29 2019 kekepower <kekepower> 1.11.5-1.mga7
+ Revision: 1361806
- Update to version 1.11.5

* Tue Jan 01 2019 kekepower <kekepower> 1.11.4-1.mga7
+ Revision: 1348383
- Update to version 1.11.4

* Sun Nov 18 2018 pterjan <pterjan> 1.11.1-3.mga7
+ Revision: 1331443
- Require go-srpm-macros rather than providing only 2 of them

* Fri Oct 19 2018 pterjan <pterjan> 1.11.1-2.mga7
+ Revision: 1322486
- Disable tests on arm too

* Wed Oct 03 2018 kekepower <kekepower> 1.11.1-1.mga7
+ Revision: 1317276
- Update to version 1.11.1

* Sat Sep 01 2018 kekepower <kekepower> 1.11-1.mga7
+ Revision: 1256105
- Update to version 1.11

* Sat Jul 07 2018 joequant <joequant> 1.10.3-1.mga7
+ Revision: 1242394
- upgrade to 1.10.3

* Sun Jun 24 2018 pterjan <pterjan> 1.10.2-2.mga7
+ Revision: 1239557
- Do not fail on tests on aarch64 for now

* Fri May 04 2018 bcornec <bcornec> 1.10.2-1.mga7
+ Revision: 1226188
- Update to upstream 1.10.2 to fix 2 CVEs

* Wed Mar 07 2018 bcornec <bcornec> 1.10-1.mga7
+ Revision: 1206994
- Update go to upstream 1.10 (needed to build docker-containerd)

* Thu Feb 08 2018 kekepower <kekepower> 1.9.4-3.mga7
+ Revision: 1199720
- Rebuild for arm

* Wed Feb 07 2018 kekepower <kekepower> 1.9.4-2.mga7
+ Revision: 1199650
- Disable go_test:archive/zip on arm

* Wed Feb 07 2018 kekepower <kekepower> 1.9.4-1.mga7
+ Revision: 1199611
- Update to version 1.9.4

* Fri Jan 26 2018 kekepower <kekepower> 1.9.3-1.mga7
+ Revision: 1197245
- Update to version 1.9.3
- Update to version 1.9.2
- Changed $RPM_BUILD_ROOT to %%{buildroot}
- Removed unused patches
- Cleaned up a little
+ bcornec <bcornec>
- Update golang to 1.8.4 (mga#21857)

* Sun Oct 15 2017 joequant <joequant> 1.9.1-1.mga7
+ Revision: 1172042
- upgrade to 1.9.1 with new build stack

* Thu Jun 22 2017 bcornec <bcornec> 1.8.1-6.mga6
+ Revision: 1108190
- Adds missing patch file for previous security fix
- Call the patch previously added in build !
- Fix #21103 CVE-2017-8932
+ pterjan <pterjan>
- Disable another test on arm
- Try fixing test exclusion
- Disable a test failing on arm

* Sun May 28 2017 akien <akien> 1.8.1-3.mga6
+ Revision: 1105389
- Fix upstream https://github.com/golang/go/issues/19155 (*_test*.go should be kept)

* Sat May 27 2017 neoclust <neoclust> 1.8.1-2.mga6
+ Revision: 1105099
- Rebuilf for ARM

* Wed Apr 19 2017 bcornec <bcornec> 1.8.1-1.mga6
+ Revision: 1096830
- Update to upstream go 1.8.1

* Sun Mar 12 2017 neoclust <neoclust> 1.6.4-2.mga6
+ Revision: 1092153
- Rebuild on armv7

* Mon Jan 02 2017 bcornec <bcornec> 1.6.4-1.mga6
+ Revision: 1079759
- Update to upstream 1.6.4 + patch to pass tests. This version is however not maintained. Will need to work on 1.7.4, but patches need to be re-written

* Tue Sep 13 2016 bcornec <bcornec> 1.6.3-2.mga6
+ Revision: 1052477
- Update to golang upstream 1.6.3 (which also fixes a CVE vulnerability)

* Sat May 07 2016 joequant <joequant> 1.6.2-7.mga6
+ Revision: 1010404
- fix rpm macros

* Sat May 07 2016 joequant <joequant> 1.6.2-6.mga6
+ Revision: 1010377
- update golang specs

* Wed May 04 2016 joequant <joequant> 1.6.2-5.mga6
+ Revision: 1009310
+ rebuild (emptylog)

* Wed May 04 2016 joequant <joequant> 1.6.2-4.mga6
+ Revision: 1009260
- rebuild to bootstrap with new golang

* Wed May 04 2016 joequant <joequant> 1.6.2-3.mga6
+ Revision: 1009252
+ rebuild (emptylog)

* Wed May 04 2016 joequant <joequant> 1.6.2-2.mga6
+ Revision: 1009239
- upgrade to 1.6.2

* Thu Feb 11 2016 umeabot <umeabot> 1.4.3-2.mga6
+ Revision: 954136
- Mageia 6 Mass Rebuild

* Mon Sep 28 2015 joequant <joequant> 1.4.3-1.mga6
+ Revision: 884364
- upgrade to 1.4.3

* Fri Jul 31 2015 joequant <joequant> 1.4.2-2.mga6
+ Revision: 859974
- add rpm macros to golang

* Thu Jul 02 2015 joequant <joequant> 1.4.2-1.mga6
+ Revision: 849505
- upgrade to 1.4.2

* Wed Oct 15 2014 umeabot <umeabot> 1.3.3-2.mga6
+ Revision: 745995
- Second Mageia 5 Mass Rebuild

* Wed Oct 01 2014 pterjan <pterjan> 1.3.3-1.mga5
+ Revision: 733807
- 1.3.3 (minor fixes)

* Sun Sep 28 2014 bcornec <bcornec> 1.3.2-2.mga5
+ Revision: 731375
- Update to upstream 1.3.2 to fix https://bugs.mageia.org/show_bug.cgi?id=14181

* Tue Sep 16 2014 umeabot <umeabot> 1.3.1-2.mga5
+ Revision: 679852
- Mageia 5 Mass Rebuild

* Sat Aug 30 2014 pterjan <pterjan> 1.3.1-1.mga5
+ Revision: 669346
- 1.3.1

* Wed Jul 02 2014 bcornec <bcornec> 1.3-3.mga5
+ Revision: 642323
- Avoid usage of a local script for building with gcc as it's then used when building other components incorerectly. Use build variables instead.

* Mon Jun 30 2014 bcornec <bcornec> 1.3-2.mga5
+ Revision: 641580
- This is now release 2
- Do not run tests for now as they abort on the build system
- Update to upstream 1.3
- Disable 2 tests that are failing in order to build it

* Mon Oct 21 2013 umeabot <umeabot> 1.1.2-3.mga4
+ Revision: 540590
- Mageia 4 Mass Rebuild

* Wed Oct 09 2013 joequant <joequant> 1.1.2-2.mga4
+ Revision: 494028
- fix vim dependency

* Tue Oct 08 2013 joequant <joequant> 1.1.2-1.mga4
+ Revision: 493484
- more spec fixups
- fixup spec
- imported package golang

